@@ -103,7 +103,7 @@ def create_default_config():
     Create default ConfigParser instance
     """
     import codecs
-    import ConfigParser
+    from notify.compat import ConfigParser
     from notify.compat import StringIO
     config = ConfigParser.SafeConfigParser()
     config.readfp(StringIO(DEFAULT_CONFIG))
@@ -114,7 +114,9 @@ def create_default_config():
         from wizard import setup_wizard
         setup_wizard(config)
     else:
-        fi = codecs.open(filename, 'r', encoding='utf-8')
-        config.readfp(fi)
-        fi.close()
+        try:
+            fi = codecs.open(filename, 'r', encoding='utf-8')
+            config.readfp(fi)
+        finally:
+            fi.close()
     return config
